trackml
=======

.. image:: https://img.shields.io/pypi/v/trackml.svg
    :target: https://pypi.python.org/pypi/trackml
    :alt: Latest PyPI version

.. image:: https://travis-ci.org/borntyping/cookiecutter-pypackage-minimal.png
   :target: https://travis-ci.org/borntyping/cookiecutter-pypackage-minimal
   :alt: Latest Travis CI build status


Usage
-----

Installation as a pip library
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
Python2:
pip install trackml

Python3:

pip3 install trackml

force refresh:
pip install --no-cache-dir --upgrade trackml
pip3 install --no-cache-dir --upgrade trackml


Requirements
^^^^^^^^^^^^


Unit Tests
^^^^^^^^^^
Install pytest:
    pip install pytest

from trackml directory run:
    $ pytest



Compatibility
-------------

License
-------

Authors
-------

`trackml` was written by `Gideon <Gideon@semantica-labs.com>`_.
